##  Sharing a Dashboard
You can share a dashboard with other users to foster collaboration and ensure that team members have access to the same insights. To view the dashboards shared with you, select Shared with me on the left-side navigation pane.
To share a dashboard from an overview page listing multiple dashboards, on the dashboard preview, click the three-dot icon > Share, select users, then click Share.
![Sharing a Dashboard from the Dashboard Preview](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274b952e7a4410149ffeafa9f07312ce_LowRes.png)
Sharing a Dashboard from the Dashboard Preview
To share a dashboard from the dashboard details page, navigate to the Shared with tab, select users, then click Share.
